interface Fathom {
    blockTrackingForMe: () => void;
    enableTrackingForMe: () => void;
    trackPageview: (opts?: PageViewOptions) => void;
    trackGoal: (code: string, cents: number) => void;
    setSite: (id: string) => void;
}
export declare type PageViewOptions = {
    url?: string;
    referrer?: string;
};
export declare type LoadOptions = {
    url?: string;
    auto?: boolean;
    honorDNT?: boolean;
    canonical?: boolean;
    includedDomains?: string[];
    excludedDomains?: string[];
    spa?: 'auto' | 'history' | 'hash';
};
declare type FathomCommand = {
    type: 'trackPageview';
    opts: PageViewOptions | undefined;
} | {
    type: 'trackGoal';
    code: string;
    cents: number;
} | {
    type: 'blockTrackingForMe';
} | {
    type: 'enableTrackingForMe';
} | {
    type: 'setSite';
    id: string;
};
declare global {
    interface Window {
        fathom?: Fathom;
        __fathomClientQueue: FathomCommand[];
    }
}
export declare const load: (siteId: string, opts?: LoadOptions) => void;
/**
 * Tracks a pageview.
 *
 * @param opts - An optional `url` or `referrer` to override auto-detected values.
 */
export declare const trackPageview: (opts?: PageViewOptions) => void;
/**
 * Tracks a goal.
 *
 * @param code - The goal ID.
 * @param cents - The value in cents.
 */
export declare const trackGoal: (code: string, cents: number) => void;
/**
 * Blocks tracking for the current visitor.
 *
 * See https://usefathom.com/docs/features/exclude
 */
export declare const blockTrackingForMe: () => void;
/**
 * Enables tracking for the current visitor.
 *
 * See https://usefathom.com/docs/features/exclude
 */
export declare const enableTrackingForMe: () => void;
/**
 * Checks if tracking is enabled for the current vistior
 */
export declare const isTrackingEnabled: () => boolean;
/**
 * Sets the Site ID.
 *
 * @param id - The new site ID.
 */
export declare const setSite: (id: string) => void;
export {};
